@@ -1,6 +1,6 @@
 # ABSTRACT: encapsulation of Dancer2 packages
 package Dancer2::Core::App;
-$Dancer2::Core::App::VERSION = '0.160003';
+$Dancer2::Core::App::VERSION = '0.161000';
 use Moo;
 use Carp               'croak';
 use Scalar::Util       'blessed';
@@ -187,8 +187,10 @@ sub _build_session_engine {
 
     Scalar::Util::weaken( my $weak_self = $self );
 
+    # Note that engine options will replace the default session_dir (if provided).
     return $self->_factory->create(
         session         => $value,
+        session_dir     => path( $self->config->{appdir}, 'sessions' ),
         %{$engine_options},
         postponed_hooks => $self->postponed_hooks,
 
@@ -302,11 +304,18 @@ has name => (
 has request => (
     is        => 'ro',
     isa       => InstanceOf['Dancer2::Core::Request'],
-    writer    => 'set_request',
+    writer    => '_set_request',
     clearer   => 'clear_request',
     predicate => 'has_request',
 );
 
+sub set_request {
+    my ($self, $request) = @_;
+    # populate request in app and all engines
+    $self->_set_request($request);
+    $_->set_request( $request ) for $self->defined_engines;
+}
+
 has response => (
     is        => 'ro',
     isa       => InstanceOf['Dancer2::Core::Response'],
@@ -1219,7 +1228,6 @@ DISPATCH:
 
         # Add request to app and engines
         $self->set_request($request);
-        $_->set_request( $request ) for $self->defined_engines;
 
         $self->log( core => "looking for $http_method $path_info" );
 
@@ -1430,7 +1438,7 @@ Dancer2::Core::App - encapsulation of Dancer2 packages
 
 =head1 VERSION
 
-version 0.160003
+version 0.161000
 
 =head1 DESCRIPTION
 
