@@ -1,6 +1,6 @@
 package Dancer2::Core::Dispatcher;
 # ABSTRACT: Class for dispatching request to the appropriate route handler
-$Dancer2::Core::Dispatcher::VERSION = '0.160003';
+$Dancer2::Core::Dispatcher::VERSION = '0.161000';
 use Moo;
 
 use Dancer2::Core::Types;
@@ -42,7 +42,10 @@ sub dispatch {
             # the app raised a flag saying it couldn't match anything
             # which is different than "I matched and it's a 404"
             delete Dancer2->runner->{'internal_404'}
-                or return $response;
+                or do {
+                    delete Dancer2->runner->{'internal_request'};
+                    return $response;
+                };
         }
 
         # don't run anymore
@@ -70,7 +73,7 @@ Dancer2::Core::Dispatcher - Class for dispatching request to the appropriate rou
 
 =head1 VERSION
 
-version 0.160003
+version 0.161000
 
 =head1 SYNOPSIS
 
