@@ -1,6 +1,6 @@
 package Dancer2::Core::Error;
 # ABSTRACT: Class representing fatal errors
-$Dancer2::Core::Error::VERSION = '0.160003';
+$Dancer2::Core::Error::VERSION = '0.161000';
 use Moo;
 use Carp;
 use Dancer2::Core::Types;
@@ -89,7 +89,7 @@ sub _build_static_page {
 
     my $filename = sprintf "%s/%d.html", $public_dir, $self->status;
 
-    open my $fh, $filename or return;
+    open my $fh, '<', $filename or return;
 
     local $/ = undef;    # slurp time
 
@@ -503,7 +503,7 @@ Dancer2::Core::Error - Class representing fatal errors
 
 =head1 VERSION
 
-version 0.160003
+version 0.161000
 
 =head1 SYNOPSIS
 
