@@ -1,6 +1,6 @@
 package Dancer2::Test;
 # ABSTRACT: Useful routines for testing Dancer2 apps
-$Dancer2::Test::VERSION = '0.160003';
+$Dancer2::Test::VERSION = '0.161000';
 use strict;
 use warnings;
 
@@ -73,7 +73,8 @@ sub dancer_response {
         no warnings qw<redefine once>;
         *Dancer2::Core::App::set_request = sub {
             my $self = shift;
-            $self->{'request'} = $request;
+            $self->_set_request( $request );
+            $_->set_request( $request ) for $self->defined_engines;
         };
     }
 
@@ -624,7 +625,7 @@ Dancer2::Test - Useful routines for testing Dancer2 apps
 
 =head1 VERSION
 
-version 0.160003
+version 0.161000
 
 =head1 SYNOPSIS
 
